@@ -28,6 +28,7 @@
 
 #include <games-gridframe.h>
 #include <games-stock.h>
+#include <games-scores.h>
 
 #include "main.h"
 #include "properties.h"
@@ -44,6 +45,22 @@ GtkWidget *window;
 GtkWidget *drawing_area;
 GtkWidget *appbar;
 
+static const GamesScoresCategory scorecats[] = {{"4.0", N_("Beginner")},
+						{"3.0", N_("Slow")},
+						{"2.0", N_("gnibbles|Medium")},
+						{"1.0", N_("Fast")},
+						{"4.1", N_("Beginner with Fakes")},
+						{"3.1", N_("Slow with Fakes")},
+						{"2.1", N_("Medium with Fakes")},
+						{"1.1", N_("Fast with Fakes")},
+						GAMES_SCORES_LAST_CATEGORY };
+static const GamesScoresDescription scoredesc = {scorecats,
+						 "4.0",
+						 "gnibbles",
+						 GAMES_SCORES_STYLE_PLAIN_DESCENDING};
+
+GamesScores *highscores;
+
 extern GdkPixmap *buffer_pixmap;
 extern GdkPixbuf *logo_pixmap;
 
@@ -144,14 +161,20 @@ about_cb (GtkAction *action, gpointer data)
 {
 	const gchar *authors[] = {"Sean MacIsaac", "Ian Peters", NULL};
 
+	const gchar *documenters[] = {"Kevin Breit", NULL};
+
 	gtk_show_about_dialog (GTK_WINDOW (window),
 			       "name", _("Nibbles"), 
 			       "version", VERSION,
-			       "copyright", "Copyright \xc2\xa9 1999-2004 Sean MacIsaac, Ian Peters",
+			       "copyright", "Copyright \xc2\xa9 1999-2006 Sean MacIsaac, Ian Peters",
+			       "license", "GPL 2+",
 			       "comments", _("A worm game for GNOME."),
 			       "authors", authors,
+			       "documenters", documenters,
 			       "translator-credits", _("translator-credits"),
 			       "logo-icon-name", "gnome-nibbles",
+			       "website", "http://www.gnome.org/projects/gnome-games/",
+			       "wrap-license", TRUE,
 			       NULL);
 }
 
@@ -563,31 +586,6 @@ main_loop (gpointer data)
 	return (TRUE);
 }
 
-void
-update_score_state (void)
-{
-        gchar **names = NULL;
-        gfloat *scores = NULL;
-        time_t *scoretimes = NULL;
-	gint top;
-
-	gchar *buf = NULL;
-	buf = g_strdup_printf ("%d.%d", properties->gamespeed,
-			       properties->fakes);
-
-	top = gnome_score_get_notable ("gnibbles", buf,
-				       &names, &scores, &scoretimes);
-	g_free (buf);
-	if (top > 0) {
-		gtk_action_set_sensitive (scores_action, TRUE);
-		g_strfreev (names);
-		g_free (scores);
-		g_free (scoretimes);
-	} else {
-		gtk_action_set_sensitive (scores_action, FALSE);
-	}
-}
-
 static gboolean
 show_cursor_cb (GtkWidget *widget, GdkEventMotion *event, gpointer data)
 {
@@ -726,6 +724,8 @@ setup_window (void)
 				     BOARDHEIGHT*5);
 	g_signal_connect (G_OBJECT (drawing_area), "expose_event",
 			G_CALLBACK (expose_event_cb), NULL);
+	/* We do our own double-buffering. */
+	gtk_widget_set_double_buffered(GTK_WIDGET (drawing_area), FALSE);
 	gtk_widget_set_events (drawing_area, GDK_BUTTON_PRESS_MASK |
 			GDK_EXPOSURE_MASK | GDK_POINTER_MOTION_MASK);
 	gtk_widget_show (drawing_area);
@@ -785,26 +785,28 @@ render_logo (void)
 int 
 main (int argc, char **argv)
 {
-	gnome_score_init ("gnibbles");
+	GnomeProgram *program;
+
+	setgid_io_init ();
 
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 	
-	gnome_program_init ("gnibbles", VERSION, LIBGNOMEUI_MODULE,
-			    argc, argv,
-			    GNOME_PARAM_POPT_TABLE, NULL,
-			    GNOME_PARAM_APP_DATADIR, REAL_DATADIR,
-			    NULL);
+	program = gnome_program_init ("gnibbles", VERSION, LIBGNOMEUI_MODULE,
+				      argc, argv,
+				      GNOME_PARAM_POPT_TABLE, NULL,
+				      GNOME_PARAM_APP_DATADIR, REAL_DATADIR,
+				      NULL);
 	gtk_window_set_default_icon_name ("gnome-nibbles");
 	srand (time (NULL));
 
+	highscores = games_scores_new (&scoredesc);
+
 	load_properties ();
 
 	setup_window ();
 
-	update_score_state ();
-
 	gnibbles_load_logo (window);
 	gnibbles_load_pixmap (window);
 
@@ -824,6 +826,8 @@ main (int argc, char **argv)
 
 	gnome_accelerators_sync();
 
+	g_object_unref (program);
+
 	return 0;
 }
 
